# iShareGIS Metalink Plugin

For each layer with an associated metadata record, add a link in the layer's option menu.

## Requirements

* iShareGIS 5.2

## Setup

### Database

Table within PostgreSQL to provide a lookup between, iShare MapSource/Layer and
Geonetwork UUID for example:

	 id |    mapsource     |   layer   |                 uuid
	----+------------------+-----------+--------------------------------------
	  1 | National/AllMaps | primary   | e234f948-2cc4-433d-9284-8b8bfff42096
	  2 | National/AllMaps | secondary | 692bf031-37d1-464f-987c-75e237d10c0d

Create table script:

	CREATE TABLE at_metadata
	(
	  id serial NOT NULL,
	  mapsource text,
	  layer text,
	  uuid text,
	  CONSTRAINT pk_at_metadata_id PRIMARY KEY (id )
	)
	WITH (
	  OIDS=FALSE
	);
	ALTER TABLE at_metadata
	  OWNER TO "iShareData";

### DataShare Connection

The metadata lookup is exposed via a DataFunc request. To enable the web service
an Internal Command DataSource is required called `at_metadata` configured with
the SQL `SELECT * FROM at_metadata`.

The following URL should return a JSON representation of the `at_metadata` table:

	getdata.aspx?Type=DataFunc&ds=at_metadata&RequestType=XSL&xsl=xml\atJSONDatatable.xsl

### iShareGIS

#### Plugin setup

Plugins for iShareGIS live in `WebApps\Web\plugins` folder each within it's own
folder. All enabled plugins must also be added to `iShareGIS.xml` within the
plugins directory. To set up the Metalink plugin:

* Create the folder `WebApps\Web\plugins\Metalink` and copy all of the Metalink files into
* Edit `WebApps\Web\plugins\iShareGIS.xml` adding `<Plugin>Metalink</Plugin>` as a child of `<PluginView>`

#### Geonetwork URL

If your metadata is not hosted in the main Astun Technology Geonetwork instance the
URL to your Geonetwork instance must be specified at the top of `Metalink.js`.

## Managing the Lookup

The `at_metadata` table is regular non-spatial PostgreSQL table which can be
edited using tools such as pgAdmin. It is also possible to edit `at_metadata`
using QGIS if you choose to "Also list tables with no geometry" when connecting
to the database. Non-spatial tables appear in the "Layers" list and you can
view and edit rows by opening the attribute table.

### MapSource Name

The `mapsource` column must contain the iShare MapSource name which a given
layer is associated with. The MapSource name can be found in Studio by
selecting the "MyMaps" item in the tree view then selecting a MapSource in the
left hand panel.

### Layer Name

The `layer` column contains the layer name used to uniquely identify a layer
within a MapSource. The layer name can be found in Studio by selecting the
layer in the tree view. The "Layer Name" field is shown in the right hand
panel. The layer name is the same as the name of the layer in the MapServer
Mapfile.

### Geonetwork UUID

The `uuid` column contains the identifier for a given metadata record within
Geonetwork. The UUID for a given metadata record can be found in Geonetwork by
either searching or browsing "Dataset" records. Once you have found a record
for which you want the UUID click the "Metadata" button to view the associated
metadata then click the star icon which provides a persistent link to the
record. The UUID is displayed in the URL of the page.
